@@ -1,8 +1,11 @@
+from typing import Optional, Sequence
+
 import dagster._check as check
 import graphene
 from dagster._core.execution.backfill import PartitionBackfill
 from dagster._core.storage.pipeline_run import RunsFilter
 from dagster._core.storage.tags import BACKFILL_ID_TAG
+from dagster._core.workspace.permissions import Permissions
 
 from ..implementation.fetch_partition_sets import (
     partition_status_counts_from_run_partition_data,
@@ -94,9 +97,9 @@ class GraphenePartitionBackfill(graphene.ObjectType):
 
     backfillId = graphene.NonNull(graphene.String)
     status = graphene.NonNull(GrapheneBulkActionStatus)
-    partitionNames = non_null_list(graphene.String)
+    partitionNames = graphene.List(graphene.NonNull(graphene.String))
     isValidSerialization = graphene.NonNull(graphene.Boolean)
-    numPartitions = graphene.NonNull(graphene.Int)
+    numPartitions = graphene.Field(graphene.Int)
     numCancelable = graphene.NonNull(graphene.Int)
     fromFailure = graphene.NonNull(graphene.Boolean)
     reexecutionSteps = graphene.List(graphene.NonNull(graphene.String))
@@ -120,6 +123,9 @@ class GraphenePartitionBackfill(graphene.ObjectType):
         "dagster_graphql.schema.partition_sets.GraphenePartitionStatusCounts"
     )
 
+    hasCancelPermission = graphene.NonNull(graphene.Boolean)
+    hasResumePermission = graphene.NonNull(graphene.Boolean)
+
     def __init__(self, backfill_job):
         self._backfill_job = check.opt_inst_param(backfill_job, "backfill_job", PartitionBackfill)
 
@@ -197,10 +203,10 @@ class GraphenePartitionBackfill(graphene.ObjectType):
     def resolve_isValidSerialization(self, _graphene_info: ResolveInfo):
         return self._backfill_job.is_valid_serialization(_graphene_info.context)
 
-    def resolve_partitionNames(self, _graphene_info: ResolveInfo):
+    def resolve_partitionNames(self, _graphene_info: ResolveInfo) -> Optional[Sequence[str]]:
         return self._backfill_job.get_partition_names(_graphene_info.context)
 
-    def resolve_numPartitions(self, _graphene_info: ResolveInfo):
+    def resolve_numPartitions(self, _graphene_info: ResolveInfo) -> Optional[int]:
         return self._backfill_job.get_num_partitions(_graphene_info.context)
 
     def resolve_numCancelable(self, _graphene_info: ResolveInfo):
@@ -243,6 +249,22 @@ class GraphenePartitionBackfill(graphene.ObjectType):
             return GraphenePythonError(self._backfill_job.error)
         return None
 
+    def resolve_hasCancelPermission(self, graphene_info):
+        if self._backfill_job.partition_set_origin is None:
+            return graphene_info.context.has_permission(Permissions.CANCEL_PARTITION_BACKFILL)
+        location_name = self._backfill_job.partition_set_origin.selector.location_name
+        return graphene_info.context.has_permission_for_location(
+            Permissions.CANCEL_PARTITION_BACKFILL, location_name
+        )
+
+    def resolve_hasResumePermission(self, graphene_info):
+        if self._backfill_job.partition_set_origin is None:
+            return graphene_info.context.has_permission(Permissions.LAUNCH_PARTITION_BACKFILL)
+        location_name = self._backfill_job.partition_set_origin.selector.location_name
+        return graphene_info.context.has_permission_for_location(
+            Permissions.LAUNCH_PARTITION_BACKFILL, location_name
+        )
+
 
 class GraphenePartitionBackfillOrError(graphene.Union):
     class Meta:
