@@ -11,6 +11,7 @@ from dagster_graphql.implementation.execution.backfill import (
     create_and_launch_partition_backfill,
     resume_partition_backfill,
 )
+from dagster_graphql.implementation.execution.dynamic_partitions import add_dynamic_partition
 from dagster_graphql.implementation.execution.launch_execution import (
     launch_pipeline_execution,
     launch_pipeline_reexecution,
@@ -57,7 +58,9 @@ from ..inputs import (
     GrapheneExecutionParams,
     GrapheneLaunchBackfillParams,
     GrapheneReexecutionParams,
+    GrapheneRepositorySelector,
 )
+from ..partition_sets import GrapheneAddDynamicPartitionResult
 from ..pipelines.pipeline import GrapheneRun
 from ..runs import (
     GrapheneLaunchRunReexecutionResult,
@@ -329,6 +332,33 @@ class GrapheneResumeBackfillMutation(graphene.Mutation):
         return resume_partition_backfill(graphene_info, backfillId)
 
 
+class GrapheneAddDynamicPartitionMutation(graphene.Mutation):
+    """Adds a partition to a dynamic partition set."""
+
+    Output = graphene.NonNull(GrapheneAddDynamicPartitionResult)
+
+    class Arguments:
+        repositorySelector = graphene.NonNull(GrapheneRepositorySelector)
+        partitionsDefName = graphene.NonNull(graphene.String)
+        partitionKey = graphene.NonNull(graphene.String)
+
+    class Meta:
+        name = "AddDynamicPartitionMutation"
+
+    @capture_error
+    @require_permission_check(Permissions.EDIT_DYNAMIC_PARTITIONS)
+    def mutate(
+        self,
+        graphene_info: ResolveInfo,
+        repositorySelector: GrapheneRepositorySelector,
+        partitionsDefName: str,
+        partitionKey: str,
+    ):
+        return add_dynamic_partition(
+            graphene_info, repositorySelector, partitionsDefName, partitionKey
+        )
+
+
 @capture_error
 def create_execution_params_and_launch_pipeline_reexec(graphene_info, execution_params_dict):
     # refactored into a helper function here in order to wrap with @capture_error,
@@ -694,3 +724,4 @@ class GrapheneDagitMutation(graphene.ObjectType):
     cancel_partition_backfill = GrapheneCancelBackfillMutation.Field()
     log_telemetry = GrapheneLogTelemetryMutation.Field()
     set_nux_seen = GrapheneSetNuxSeenMutation.Field()
+    add_dynamic_partition = GrapheneAddDynamicPartitionMutation.Field()
