@@ -15,8 +15,10 @@ from dagster._core.execution.backfill import BulkActionStatus
 from dagster._core.nux import get_has_seen_nux
 from dagster._core.scheduler.instigation import InstigatorType
 
+from dagster_graphql.implementation.fetch_env_vars import get_utilized_env_vars_or_error
 from dagster_graphql.implementation.fetch_logs import get_captured_log_metadata
 from dagster_graphql.implementation.fetch_runs import get_assets_latest_info
+from dagster_graphql.schema.env_vars import GrapheneEnvVarWithConsumersListOrError
 
 from ...implementation.external import (
     fetch_location_statuses,
@@ -122,11 +124,12 @@ from ..runs import (
     GrapheneRunGroupsOrError,
     GrapheneRuns,
     GrapheneRunsOrError,
+    GrapheneRunTagKeysOrError,
+    GrapheneRunTagsOrError,
     parse_run_config_input,
 )
 from ..schedules import GrapheneScheduleOrError, GrapheneSchedulerOrError, GrapheneSchedulesOrError
 from ..sensors import GrapheneSensorOrError, GrapheneSensorsOrError
-from ..tags import GraphenePipelineTagAndValues
 from ..test import GrapheneTestFields
 from ..util import ResolveInfo, get_compute_log_manager, non_null_list
 from .assets import GrapheneAssetOrError, GrapheneAssetsOrError
@@ -220,6 +223,12 @@ class GrapheneDagitQuery(graphene.ObjectType):
         description="Retrieve all the top level resources.",
     )
 
+    utilizedEnvVarsOrError = graphene.Field(
+        graphene.NonNull(GrapheneEnvVarWithConsumersListOrError),
+        repositorySelector=graphene.NonNull(GrapheneRepositorySelector),
+        description="Retrieve all the utilized environment variables for the given repo.",
+    )
+
     sensorOrError = graphene.Field(
         graphene.NonNull(GrapheneSensorOrError),
         sensorSelector=graphene.NonNull(GrapheneSensorSelector),
@@ -291,11 +300,11 @@ class GrapheneDagitQuery(graphene.ObjectType):
         runId=graphene.NonNull(graphene.ID),
         description="Retrieve a run by its run id.",
     )
-    runTagKeys = graphene.Field(
-        non_null_list(graphene.String), description="Retrieve the distinct tag keys from all runs."
+    runTagKeysOrError = graphene.Field(
+        GrapheneRunTagKeysOrError, description="Retrieve the distinct tag keys from all runs."
     )
-    runTags = graphene.Field(
-        non_null_list(GraphenePipelineTagAndValues),
+    runTagsOrError = graphene.Field(
+        GrapheneRunTagsOrError,
         tagKeys=graphene.Argument(graphene.List(graphene.NonNull(graphene.String))),
         valuePrefix=graphene.String(),
         limit=graphene.Int(),
@@ -535,6 +544,12 @@ class GrapheneDagitQuery(graphene.ObjectType):
             RepositorySelector.from_graphql_input(kwargs.get("repositorySelector")),
         )
 
+    def resolve_utilizedEnvVarsOrError(self, graphene_info: ResolveInfo, **kwargs):
+        return get_utilized_env_vars_or_error(
+            graphene_info,
+            RepositorySelector.from_graphql_input(kwargs.get("repositorySelector")),
+        )
+
     def resolve_sensorOrError(
         self, graphene_info: ResolveInfo, sensorSelector: GrapheneRepositorySelector
     ):
@@ -636,10 +651,10 @@ class GrapheneDagitQuery(graphene.ObjectType):
             partitionSetName,  # type: ignore
         )
 
-    def resolve_runTagKeys(self, graphene_info: ResolveInfo):
+    def resolve_runTagKeysOrError(self, graphene_info: ResolveInfo):
         return get_run_tag_keys(graphene_info)
 
-    def resolve_runTags(
+    def resolve_runTagsOrError(
         self,
         graphene_info: ResolveInfo,
         tagKeys: Optional[List[str]] = None,
